using UnityEngine;
using Entitas;
using System.Collections.Generic;

public class AddViewSystem : ReactiveSystem<GameEntity>
{
    private readonly Contexts _contexts;
    public AddViewSystem(Contexts contexts) : base(contexts.game)
    {
        _contexts = contexts;
    }

    protected override void Execute(List<GameEntity> entities)
    {
        foreach(var entity in entities)
        {
            var obj = SpawnObj(entity);
            entity.AddViewComp(obj);
            entity.RemoveCreatObjectCmdComp();
        }
    }

    protected override bool Filter(GameEntity entity)
    {
        return true;
    }

    protected override ICollector<GameEntity> GetTrigger(IContext<GameEntity> context)
    {
        return context.CreateCollector(GameMatcher.CreatObjectCmdComp);
    }

    private GameObject SpawnObj(GameEntity gameEntity)
    {
        var path = gameEntity.creatObjectCmdComp.path;
        var prefab = Resources.Load<GameObject>(path);
        var obj = GameObject.Instantiate(prefab,Vector3.zero,Quaternion.identity);
        var view = obj.GetComponent<View>();
        view.Link(_contexts, gameEntity);
        return obj;
    }
}
